@@ -69,9 +69,8 @@ gjs_foreign_load_foreign_module(JSContext *context,
         if (strcmp(gi_namespace, foreign_modules[i].gi_namespace) != 0)
             continue;
 
-        if (foreign_modules[i].loaded) {
+        if (foreign_modules[i].loaded)
             return JS_TRUE;
-        }
 
         // FIXME: Find a way to check if a module is imported
         //        and only execute this statement if isn't
@@ -86,9 +85,10 @@ gjs_foreign_load_foreign_module(JSContext *context,
         }
         g_free(script);
         foreign_modules[i].loaded = TRUE;
+        return JS_TRUE;
     }
 
-    return JS_TRUE;
+    return JS_FALSE;
 }
 
 JSBool
