@@ -290,7 +290,9 @@ gjs_callback_closure(ffi_cif *cif,
 
     if (n_outargs == 0 && !ret_type_is_void) {
         GIArgument argument;
+        GITransfer transfer;
 
+        transfer = g_callable_info_get_caller_owns (trampoline->info);
         /* non-void return value, no out args. Should
          * be a single return value. */
         if (!gjs_value_to_g_argument(context,
@@ -298,7 +300,7 @@ gjs_callback_closure(ffi_cif *cif,
                                      &ret_type,
                                      "callback",
                                      GJS_ARGUMENT_RETURN_VALUE,
-                                     GI_TRANSFER_NOTHING,
+                                     transfer,
                                      TRUE,
                                      &argument))
             goto out;
@@ -1199,6 +1201,23 @@ release:
             if (arg_failed)
                 postinvoke_release_failed = TRUE;
 
+            /* Free GArgument, the jsval should have ref'd or copied it */
+            transfer = g_arg_info_get_ownership_transfer(&arg_info);
+            if (!arg_failed) {
+                if (array_length_pos >= 0) {
+                    gjs_g_argument_release_out_array(context,
+                                                     transfer,
+                                                     &arg_type_info,
+                                                     JSVAL_TO_INT(array_length),
+                                                     arg);
+                } else {
+                    gjs_g_argument_release(context,
+                                           transfer,
+                                           &arg_type_info,
+                                           arg);
+                }
+            }
+
             /* For caller-allocates, what happens here is we allocate
              * a structure above, then gjs_value_from_g_argument calls
              * g_boxed_copy on it, and takes ownership of that.  So
@@ -1230,23 +1249,6 @@ release:
                 g_base_info_unref((GIBaseInfo*)interface_info);
             }
 
-            /* Free GArgument, the jsval should have ref'd or copied it */
-            transfer = g_arg_info_get_ownership_transfer(&arg_info);
-            if (!arg_failed) {
-                if (array_length_pos >= 0) {
-                    gjs_g_argument_release_out_array(context,
-                                                     transfer,
-                                                     &arg_type_info,
-                                                     JSVAL_TO_INT(array_length),
-                                                     arg);
-                } else {
-                    gjs_g_argument_release(context,
-                                           transfer,
-                                           &arg_type_info,
-                                           arg);
-                }
-            }
-
             ++next_rval;
         }
     }
@@ -1300,25 +1302,27 @@ function_call(JSContext *context,
               unsigned   js_argc,
               jsval     *vp)
 {
-    jsval *js_argv = JS_ARGV(context, vp);
-    JSObject *object = JS_THIS_OBJECT(context, vp);
-    JSObject *callee = JSVAL_TO_OBJECT(JS_CALLEE(context, vp));
+    JS::CallArgs js_argv = JS::CallArgsFromVp (js_argc, vp);
+    JSObject *object = JSVAL_TO_OBJECT(js_argv.thisv());
+    JSObject *callee = &js_argv.callee();
+
     JSBool success;
     Function *priv;
     jsval retval;
 
     priv = priv_from_js(context, callee);
-    gjs_debug_marshal(GJS_DEBUG_GFUNCTION, "Call callee %p priv %p this obj %p %s", callee, priv,
-                      obj, JS_GetTypeName(context,
-                                          JS_TypeOfValue(context, OBJECT_TO_JSVAL(object))));
+    gjs_debug_marshal(GJS_DEBUG_GFUNCTION,
+                      "Call callee %p priv %p this obj %p %s", callee, priv,
+                      object,
+                      JS_GetTypeName(context, JS_TypeOfValue(context, OBJECT_TO_JSVAL(object))));
 
     if (priv == NULL)
         return JS_TRUE; /* we are the prototype, or have the wrong class */
 
 
-    success = gjs_invoke_c_function(context, priv, object, js_argc, js_argv, &retval, NULL);
+    success = gjs_invoke_c_function(context, priv, object, js_argc, js_argv.array(), &retval, NULL);
     if (success)
-        JS_SET_RVAL(context, vp, retval);
+        js_argv.rval().set(retval);
 
     return success;
 }
@@ -1367,6 +1371,8 @@ get_num_arguments (JSContext *context,
     jsval retval;
     Function *priv;
 
+    JS::CallReceiver rec = JS::CallReceiverFromVp(vp.address());
+
     priv = priv_from_js(context, obj);
 
     if (priv == NULL)
@@ -1387,7 +1393,7 @@ get_num_arguments (JSContext *context,
     }
 
     retval = INT_TO_JSVAL(n_jsargs);
-    JS_SET_RVAL(context, vp.address(), retval);
+    rec.rval().set(retval);
     return JS_TRUE;
 }
 
@@ -1406,7 +1412,9 @@ function_to_string (JSContext *context,
     GString *arg_names_str;
     gchar *arg_names;
 
-    self = JS_THIS_OBJECT(context, vp);
+    JS::CallReceiver rec = JS::CallReceiverFromVp(vp);
+    self = JSVAL_TO_OBJECT(rec.thisv());
+
     if (!self) {
         gjs_throw(context, "this cannot be null");
         return JS_FALSE;
@@ -1458,7 +1466,7 @@ function_to_string (JSContext *context,
 
  out:
     if (gjs_string_from_utf8(context, string, -1, &retval)) {
-        JS_SET_RVAL(context, vp, retval);
+        rec.rval().set(retval);
         ret = JS_TRUE;
     }
 
