@@ -96,15 +96,8 @@ gjs_string_from_utf8(JSContext  *context,
 
     JS_BeginRequest(context);
 
-    if (g_mem_is_system_malloc()) {
-        /* Avoid a copy - assumes that g_malloc == js_malloc == malloc */
-        str = JS_NewUCString(context, u16_string, u16_string_length);
-    } else {
-        str = JS_NewUCStringCopyN(context,
-                                (jschar*)u16_string,
-                                u16_string_length);
-        g_free(u16_string);
-    }
+    /* Avoid a copy - assumes that g_malloc == js_malloc == malloc */
+    str = JS_NewUCString(context, u16_string, u16_string_length);
 
     if (str && value_p)
         *value_p = STRING_TO_JSVAL(str);
