@@ -45,6 +45,7 @@ const MyComplexGtkSubclass = new Lang.Class({
     Template: ByteArray.fromString(template),
     Children: ['label-child', 'label-child2'],
     InternalChildren: ['internal-label-child'],
+    CssName: 'complex-subclass',
 
     _init: function(params) {
         this.parent(params);
@@ -54,6 +55,9 @@ const MyComplexGtkSubclass = new Lang.Class({
 
         JSUnit.assertNotEquals(this.label_child2, null);
         JSUnit.assertNotEquals(this._internal_label_child, null);
+
+        JSUnit.assertEquals(Gtk.Widget.get_css_name.call(MyComplexGtkSubclass),
+                            'complex-subclass');
     }
 });
 
@@ -93,12 +97,4 @@ function testGtk() {
     validateTemplate(new MyComplexGtkSubclassFromResource());
 }
 
-// https://bugzilla.gnome.org/show_bug.cgi?id=704842
-function testGdkKeymap() {
-    Gtk.init(null);
-
-    let keymap = Gdk.Keymap.get_default();
-    JSUnit.assertNotEquals(keymap.get_entries_for_keyval(Gdk.KEY_a), null);
-}
-
 JSUnit.gjstestRun(this, JSUnit.setUp, JSUnit.tearDown);
